==> gnumeric-1.3.0.tar.gz: gnumeric-1.3.0/src/cut-n-paste-code/goffice/gui-utils/go-action-combo-pixmaps.h <==
/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * go-action-combo-pixmaps.h: A custom GtkAction to chose among a set of images
 *
 * Copyright (C) 2004 Jody Goldberg (jody@gnome.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/

#ifndef __GO_ACTION_COMBO_PIXMAPS_H__
#define __GO_ACTION_COMBO_PIXMAPS_H__

#include <glib-object.h>
#include <goffice/gui-utils/go-combo-pixmaps.h>

G_BEGIN_DECLS

#define GO_ACTION_COMBO_PIXMAPS_TYPE  (go_action_combo_pixmaps_get_type ())
#define GO_ACTION_COMBO_PIXMAPS(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_ACTION_COMBO_PIXMAPS_TYPE, GOActionComboPixmaps))
#define IS_GO_ACTION_COMBO_PIXMAPS(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_ACTION_COMBO_PIXMAPS_TYPE))

typedef struct _GOActionComboPixmaps	 GOActionComboPixmaps;
typedef struct {
	char const *untranslated_tooltip;
	guint8 const *inline_gdkpixbuf;
	int id;
} GOActionComboPixmapsElement;

GType	go_action_combo_pixmaps_get_type (void);
GOActionComboPixmaps *
	go_action_combo_pixmaps_new (char const *name,
				     GOActionComboPixmapsElement const *elements,
				     int ncols, int nrows);
int	go_action_combo_pixmaps_get_selection (GOActionComboPixmaps *action);

G_END_DECLS

#endif  /* __GO_ACTION_COMBO_PIXMAPS_H__ */

==> gnumeric_1.4.3.orig.tar.gz: gnumeric-1.4.3/src/cut-n-paste-code/goffice/gui-utils/go-action-combo-pixmaps.h <==
/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * go-action-combo-pixmaps.h: A custom GtkAction to chose among a set of images
 *
 * Copyright (C) 2004 Jody Goldberg (jody@gnome.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/

#ifndef __GO_ACTION_COMBO_PIXMAPS_H__
#define __GO_ACTION_COMBO_PIXMAPS_H__

#include <glib-object.h>
#include <goffice/gui-utils/go-combo-pixmaps.h>

G_BEGIN_DECLS

#define GO_ACTION_COMBO_PIXMAPS_TYPE  (go_action_combo_pixmaps_get_type ())
#define GO_ACTION_COMBO_PIXMAPS(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_ACTION_COMBO_PIXMAPS_TYPE, GOActionComboPixmaps))
#define IS_GO_ACTION_COMBO_PIXMAPS(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_ACTION_COMBO_PIXMAPS_TYPE))

typedef struct _GOActionComboPixmaps	 GOActionComboPixmaps;
typedef struct {
	char const *untranslated_tooltip;
	char const *stock_id;
	int id;
} GOActionComboPixmapsElement;

GType	go_action_combo_pixmaps_get_type (void);
GOActionComboPixmaps *
	go_action_combo_pixmaps_new (char const *name,
				     GOActionComboPixmapsElement const *elements,
				     int ncols, int nrows);
int	 go_action_combo_pixmaps_get_selected (GOActionComboPixmaps *action, int *indx);
gboolean go_action_combo_pixmaps_select_id    (GOActionComboPixmaps *action, int id);

G_END_DECLS

#endif  /* __GO_ACTION_COMBO_PIXMAPS_H__ */
